import { setConfig } from '@/modules/config.ts';
import { useConfig, fileIsExist } from '@kevisual/use-config';
import fs from 'fs';
import path from 'path';

// 只获取文件列表
const getMusicList = async (musicDir: string) => {
  const musicList = fs.readdirSync(musicDir);
  // 只获取文件列表
  const fileList = musicList.filter((item) => {
    return fs.statSync(path.join(musicDir, item)).isFile();
  });
  return fileList;
};

const config = useConfig();
export class MusicService {
  musicDir: string;
  constructor() {
    this.musicDir = config.musicDir || '';
  }
  setMusicDir(musicDir: string) {
    musicDir = musicDir.replace(/"/g, '');
    const _musicDir = path.resolve(musicDir);
    if (fileIsExist(_musicDir)) {
      this.musicDir = musicDir;
      setConfig({
        musicDir: _musicDir,
      });
      return {
        code: 200,
        message: 'musicDir is set success',
      };
    } else {
      return {
        code: 400,
        message: 'musicDir is not exist',
      };
    }
  }
  async getMusicList() {
    const musicList = await getMusicList(this.musicDir);
    return musicList;
  }
  getRealPath(file: string) {
    // file 如果有空格，则需要转义
    // 如果有"" 则移除
    const realPath = path.join(this.musicDir, file.replace(/"/g, ''));
    console.log('realPath', realPath);
    if (fileIsExist(realPath)) {
      return realPath;
    }
    return null;
  }
}
